@@ -1,5 +1,5 @@
+mod generate;
 mod parse;
-mod repr;
 
 use proc_macro2::TokenStream;
 
@@ -8,7 +8,7 @@ pub fn shader_repr(attr: proc_macro::TokenStream, item: proc_macro::TokenStream)
         Ok(input) => {
             let struct_item = &input.item_struct;
             std::iter::once(quote::quote!(#struct_item))
-                .chain(Some(repr::generate_repr(&input)))
+                .chain(Some(generate::generate_repr(&input)))
                 // .chain(Some(generate_glsl_type(&input)))
                 .collect::<TokenStream>()
         }
